API docs for “spamfighter.core.message.attribute.IPAttributeDomain”

# Class s.c.m.a.IPAttributeDomain(AttributeDomain):

Part of spamfighter.core.message.attribute View Source View In Hierarchy

Атрибут, в котором хранится IP.

Method | serialize | Получить сериализованное значение атрибута.
Method | deserialize | Десериализовать значение в атрибут.

Inherited from AttributeDomain:

Method | __init__ | Конструктор.
Method | name | Получить имя атрибута.
Method | __eq__ | Undocumented
Method | __repr__ | Undocumented

def serialize(self, attribute): (source)
overrides spamfighter.core.message.attribute.AttributeDomain.serialize
Получить сериализованное значение атрибута.

Parameters | attribute | атрибут (type: `IAttribute` )
Returns | сериализованное значение атрибута

def deserialize(self, value): (source)
overrides spamfighter.core.message.attribute.AttributeDomain.deserialize
Десериализовать значение в атрибут.

Parameters | value | сериализованное значение
Returns | атрибут (type: `IAttribute` )